@@ -5,6 +5,9 @@ DISPENSED = "dispensed"
 FILLED = "filled"
 IN_PROGRESS_APPT = "in_progress"
 PARTIAL = "partial"
+PER_DAY = "day"
+PER_HR = "hr"
 PRESCRIPTION_ACTION = "prescription"
 PRINT_SELECTED = "print_selected"
+SINGLE = "single"
 SOLUTION = "SOLUTION"
