@@ -8,10 +8,10 @@ from .labels_form import LabelsForm
 from .medication_form import MedicationForm
 from .medication_lot_form import MedicationLotForm
 from .medication_order_form import MedicationOrderForm
-from .medication_product_form import MedicationProductForm
-from .medication_stock_create_labels_form import MedicationStockCreateLabelsForm
-from .medication_stock_form import MedicationStockForm
-from .medication_stock_receiving_form import MedicationStockReceivingForm
+from .product_form import ProductForm
 from .return_history_form import ReturnHistoryForm
 from .rx_form import RxForm
 from .rx_refill_form import RxRefillForm
+from .stock_create_labels_form import StockCreateLabelsForm
+from .stock_form import StockForm
+from .stock_receiving_form import StockReceivingForm
